{% extends "!layout.html" %}
{% block rootrellink %}
  <li>
    <img src="{{ pathto('_static/ycm-logo-16.png', 1) }}" alt=""
         style="vertical-align: middle; margin-top: -2px" />
  </li>
  <li>
    <a href="https://github.com/robotology/ycm/">YCM</a>{{ reldelim1 }}
  </li>
  <li>
    <a href="{{ pathto(master_doc) }}">{{ shorttitle|e }}</a>{{ reldelim1 }}
  </li>
{% endblock %}
